# Table of Contents

- [navigation](<./navigation.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Navigating SAP LeanIX](<./Navigating-SAP-LeanIX.md>)
  - [Was this page helpful?](<./Navigating-SAP-LeanIX/Was-this-page-helpful.md>)
  - [We'd love your feedback!](<./Navigating-SAP-LeanIX/Wed-love-your-feedback.md>)
